==> pluxml_5.3.orig.tar.gz: PluXml-5.3/core/lang/pt/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Português',

# common
'L_PLUXML_VERSION'				=> 'Versão de Pluxml',
'L_HOMEPAGE'					=> 'Índice',
'L_UNCLASSIFIED'				=> 'Não categorizado;',
'L_INFO_PHP_VERSION'			=> 'Versão de php',
'L_INFO_MAGIC_QUOTES'			=> 'Estado dos "magic quotes"',
'L_INFO_CHARSET'				=> 'codagem',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Tema principal PluXml não foi encontrado',
'L_ERR_FILE_NOTFOUND'			=> 'O ficheiro de destino PluXml não foi encontrado',
'L_ERR_PAGE_NOT_FOUND'			=> 'Página não encontrada',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'jan',
'L_SHORT_FEBRUARY'				=> 'fev',
'L_SHORT_MARCH'					=> 'março',
'L_SHORT_APRIL'					=> 'abril',
'L_SHORT_MAY'					=> 'maio',
'L_SHORT_JUNE'					=> 'junho',
'L_SHORT_JULY'					=> 'julho',
'L_SHORT_AUGUST'				=> 'agosto',
'L_SHORT_SEPTEMBER'				=> 'set',
'L_SHORT_OCTOBER'				=> 'out',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dez',
'L_JANUARY'						=> 'Janeiro',
'L_FEBRUARY'					=> 'Fevereiro',
'L_MARCH'						=> 'Março',
'L_APRIL'						=> 'Avril',
'L_MAY'							=> 'Maio',
'L_JUNE'						=> 'Junho',
'L_JULY'						=> 'Julho',
'L_AUGUST'						=> 'Agosto',
'L_SEPTEMBER'					=> 'Setembro',
'L_OCTOBER'						=> 'Outubro',
'L_NOVEMBER'					=> 'Novembro',
'L_DECEMBER'					=> 'Dezembro',
'L_MONDAY'						=> 'Segunda-feira',
'L_TUESDAY'						=> 'Terça-feira',
'L_WEDNESDAY'					=> 'Quarta-feira',
'L_THURSDAY'					=> 'Quinta-feira',
'L_FRIDAY'						=> 'Sexta-feira',
'L_SATURDAY'					=> 'Sábado',
'L_SUNDAY'						=> 'Domingo',

# class.plx.capcha.php
'L_LAST'						=> 'ultima',
'L_FIRST'						=> 'primeira',
'L_SECOND'						=> 'segunda',
'L_THIRD'						=> 'terceira',
'L_FOURTH'						=> 'quarta',
'L_FIFTH'						=> 'quinta',
'L_SIXTH'						=> 'sexta',
'L_SEVENTH'						=> 'sétima',
'L_EIGTH'						=> 'oitáva',
'L_NINTH'						=> 'nôna',
'L_TENTH'						=> 'décima',
'L_NTH'							=> 'èsima',
'L_CAPCHA_QUESTION'				=> 'Dígite a <span class="capcha-letter">%s</span> lêtra da palavra <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s é accessivél em escritura',
'L_WRITE_NOT_ACCESS'			=> '%s não é accessivél em escritura ou não existe',
'L_MODREWRITE_AVAILABLE'		=> 'Módulo apache de reescrever URLS  "mod_rewrite" disponivél',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Módulo apache de reescrever URLS  "mod_rewrite" indisponivél',
'L_LIBGD_INSTALLED'				=> 'Bibliotéca GD instalada',
'L_LIBGD_NOT_INSTALLED'			=> 'Bibliotéca GD não instalada',
'L_MAIL_AVAILABLE'				=> 'Função de envio de e-mail disponivél',
'L_MAIL_NOT_AVAILABLE'			=> 'Função de envio de e-mail indisponivél',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'O ficheiro"%sversion" é necessário ao funcionamento de PluXml',
'L_ARTICLE_NO_TAG'				=> 'Nenhum artigo correspondente a este tag; !',
'L_UNKNOWN_CATEGORY'			=> 'Esta categorai não existe !',
'L_NO_ARTICLE_PAGE'				=> 'Nenhum artigo correspondente a esta página !',
'L_UNKNOWN_ARTICLE'				=> 'Este artigo nunca existiu ou foi suprimido !',
'L_COM_IN_MODERATION'			=> 'O comentário em espera de moderação pelo administrador',
'L_UNKNOWN_STATIC'				=> 'Cette page n\'existe pas ou n\'existe plus !',
'L_DOCUMENT_NOT_FOUND'			=> 'O documentos especificado não foi encontrado',
'L_NEWCOMMENT_ERR'				=> 'Ocorreu um erro durante a publicação do comentário',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Queira por favor preenchêr todos os campos obrigatórios',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'A verificação anti-spam está incorrecta, tente novamente;',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compressão %s activada',
'L_PAGETITLE_ARCHIVES'			=> 'Arquivos',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'nenhuma categoria',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorias',
'L_NO_ARTICLE'					=> 'nenhum artigo',
'L_ARTICLE'						=> 'artigo',
'L_ARTICLES'					=> 'artigos',
'L_ARTAUTHOR_UNKNOWN'			=> 'desconhecido',
'L_ARTTAGS_NONE'				=> 'sem tags',
'L_ARTCHAPO'					=> 'Lêr mais #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Fluxo Rss dos artigos desta categoria',
'L_ARTFEED_RSS_TAG'				=> 'Fluxo Rss dos artigos deste tag',
'L_ARTFEED_RSS'					=> 'Fluxo Rss dos artigos',
'L_NO_COMMENT'					=> 'não comentários',
'L_COMMENT'						=> 'comentário',
'L_COMMENTS'					=> 'comentários',
'L_COMFEED_RSS_ARTICLE'			=> 'Fluxo Rss dos comentários deste artigo',
'L_COMFEED_RSS'					=> 'Fluxo Rss dos comentários',
'L_STATICCONTENT_INPROCESS'		=> 'Esta página está actualmente em curso de redacção',
'L_SAID'						=> 'escreveu',

'L_PAGINATION_FIRST_TITLE'		=> 'Ir á primeira página',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Anterior',
'L_PAGINATION_PREVIOUS'			=> 'anterior',
'L_PAGINATION_NEXT_TITLE'		=> 'Seguinte',
'L_PAGINATION_NEXT'				=> 'seguinte',
'L_PAGINATION_LAST_TITLE'		=> 'Ir á ultima página',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'página %s de %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Os URLS privados não foram inicializados nos parâmetros de administração !',
'L_FEED_COMMENTS'				=> 'Comentários',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentários online',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentários offline',
'L_FEED_WRITTEN_BY'				=> 'Escrito por',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/pt/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Português',

'L_DATE_CREATION'				=> 'Data de criação',
'L_DATE_UPDATE'					=> 'Data atualizada',

# common
'L_PLUXML_VERSION'				=> 'Versão de Pluxml',
'L_HOMEPAGE'					=> 'Índice',
'L_UNCLASSIFIED'				=> 'Não categorizado;',
'L_INFO_PHP_VERSION'			=> 'Versão de php',
'L_INFO_MAGIC_QUOTES'			=> 'Estado dos "magic quotes"',
'L_INFO_CHARSET'				=> 'codagem',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'Tema principal PluXml não foi encontrado',
'L_ERR_FILE_NOTFOUND'			=> 'O ficheiro de destino PluXml não foi encontrado',
'L_ERR_PAGE_NOT_FOUND'			=> 'Página não encontrada',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'jan',
'L_SHORT_FEBRUARY'				=> 'fev',
'L_SHORT_MARCH'					=> 'março',
'L_SHORT_APRIL'					=> 'abril',
'L_SHORT_MAY'					=> 'maio',
'L_SHORT_JUNE'					=> 'junho',
'L_SHORT_JULY'					=> 'julho',
'L_SHORT_AUGUST'				=> 'agosto',
'L_SHORT_SEPTEMBER'				=> 'set',
'L_SHORT_OCTOBER'				=> 'out',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dez',
'L_JANUARY'						=> 'Janeiro',
'L_FEBRUARY'					=> 'Fevereiro',
'L_MARCH'						=> 'Março',
'L_APRIL'						=> 'Avril',
'L_MAY'							=> 'Maio',
'L_JUNE'						=> 'Junho',
'L_JULY'						=> 'Julho',
'L_AUGUST'						=> 'Agosto',
'L_SEPTEMBER'					=> 'Setembro',
'L_OCTOBER'						=> 'Outubro',
'L_NOVEMBER'					=> 'Novembro',
'L_DECEMBER'					=> 'Dezembro',
'L_MONDAY'						=> 'Segunda-feira',
'L_TUESDAY'						=> 'Terça-feira',
'L_WEDNESDAY'					=> 'Quarta-feira',
'L_THURSDAY'					=> 'Quinta-feira',
'L_FRIDAY'						=> 'Sexta-feira',
'L_SATURDAY'					=> 'Sábado',
'L_SUNDAY'						=> 'Domingo',

# class.plx.capcha.php
'L_LAST'						=> 'ultima',
'L_FIRST'						=> 'primeira',
'L_SECOND'						=> 'segunda',
'L_THIRD'						=> 'terceira',
'L_FOURTH'						=> 'quarta',
'L_FIFTH'						=> 'quinta',
'L_SIXTH'						=> 'sexta',
'L_SEVENTH'						=> 'sétima',
'L_EIGTH'						=> 'oitáva',
'L_NINTH'						=> 'nôna',
'L_TENTH'						=> 'décima',
'L_NTH'							=> 'èsima',
'L_CAPCHA_QUESTION'				=> 'Dígite a <span class="capcha-letter">%s</span> lêtra da palavra <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s é accessivél em escritura',
'L_WRITE_NOT_ACCESS'			=> '%s não é accessivél em escritura ou não existe',
'L_MODREWRITE_AVAILABLE'		=> 'Módulo apache de reescrever URLS  "mod_rewrite" disponivél',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Módulo apache de reescrever URLS  "mod_rewrite" indisponivél',
'L_LIBGD_INSTALLED'				=> 'Bibliotéca GD instalada',
'L_LIBGD_NOT_INSTALLED'			=> 'Bibliotéca GD não instalada',
'L_MAIL_AVAILABLE'				=> 'Função de envio de e-mail disponivél',
'L_MAIL_NOT_AVAILABLE'			=> 'Função de envio de e-mail indisponivél',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'Nenhum artigo correspondente a este tag; !',
'L_UNKNOWN_CATEGORY'			=> 'Esta categorai não existe !',
'L_NO_ARTICLE_PAGE'				=> 'Nenhum artigo correspondente a esta página !',
'L_UNKNOWN_ARTICLE'				=> 'Este artigo nunca existiu ou foi suprimido !',
'L_COM_IN_MODERATION'			=> 'O comentário em espera de moderação pelo administrador',
'L_UNKNOWN_STATIC'				=> 'Cette page n\'existe pas ou n\'existe plus !',
'L_DOCUMENT_NOT_FOUND'			=> 'O documentos especificado não foi encontrado',
'L_NEWCOMMENT_ERR'				=> 'Ocorreu um erro durante a publicação do comentário',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Queira por favor preenchêr todos os campos obrigatórios',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'A verificação anti-spam está incorrecta, tente novamente;',

# class.plx.show.php

'L_HTTPENCODING'				=> 'Compressão %s activada',
'L_PAGETITLE_ARCHIVES'			=> 'Arquivos',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'nenhuma categoria',
'L_CATEGORY'					=> 'categoria',
'L_CATEGORIES'					=> 'categorias',
'L_NO_ARTICLE'					=> 'nenhum artigo',
'L_ARTICLE'						=> 'artigo',
'L_ARTICLES'					=> 'artigos',
'L_ARTAUTHOR_UNKNOWN'			=> 'desconhecido',
'L_ARTTAGS_NONE'				=> 'sem tags',
'L_ARTCHAPO'					=> 'Lêr mais #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Fluxo Rss dos artigos desta categoria',
'L_ARTFEED_RSS_TAG'				=> 'Fluxo Rss dos artigos deste tag',
'L_ARTFEED_RSS'					=> 'Fluxo Rss dos artigos',
'L_NO_COMMENT'					=> 'não comentários',
'L_COMMENT'						=> 'comentário',
'L_COMMENTS'					=> 'comentários',
'L_COMFEED_RSS_ARTICLE'			=> 'Fluxo Rss dos comentários deste artigo',
'L_COMFEED_RSS'					=> 'Fluxo Rss dos comentários',
'L_STATICCONTENT_INPROCESS'		=> 'Esta página está actualmente em curso de redacção',
'L_SAID'						=> 'escreveu',

'L_PAGINATION_FIRST_TITLE'		=> 'Ir á primeira página',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Anterior',
'L_PAGINATION_PREVIOUS'			=> 'anterior',
'L_PAGINATION_NEXT_TITLE'		=> 'Seguinte',
'L_PAGINATION_NEXT'				=> 'seguinte',
'L_PAGINATION_LAST_TITLE'		=> 'Ir á ultima página',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'página %s de %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Os URLS privados não foram inicializados nos parâmetros de administração !',
'L_FEED_COMMENTS'				=> 'Comentários',
'L_FEED_ONLINE_COMMENTS'		=> 'Comentários online',
'L_FEED_OFFLINE_COMMENTS'		=> 'Comentários offline',
'L_FEED_WRITTEN_BY'				=> 'Escrito por',

);
?>
